DO NOT REPLY [Bug 48179] After startup seeing java.io.FileNotFoundException:/tldcache.ser (No such file or directory)

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48179

Konstantin Kolinko  changed:

   What|Removed |Added

 Status|REOPENED|RESOLVED
 Resolution||FIXED

--- Comment #7 from Konstantin Kolinko  2010-05-25 
22:53:14 EDT ---
This has been fixed in 5.5 in r948296 and will be in 5.5.30 onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948296 - in /tomcat/tc5.5.x/trunk: STATUS.txt container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties container/catalina/src/share/org/apache/catalina/startup/Tld

2010-05-25 Thread kkolinko
Author: kkolinko
Date: Wed May 26 02:49:51 2010
New Revision: 948296

URL: http://svn.apache.org/viewvc?rev=948296&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=48179
Improve processing of TLD cache file:
- log TLD cache reading and writing errors
- if reading a TLD cache fails then continue TLD scanning, instead of quiting
- use finally{} block to close input/output streams when reading/writing the 
file

Modified:
tomcat/tc5.5.x/trunk/STATUS.txt

tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties

tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/TldConfig.java
tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml

Modified: tomcat/tc5.5.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/STATUS.txt?rev=948296&r1=948295&r2=948296&view=diff
==
--- tomcat/tc5.5.x/trunk/STATUS.txt (original)
+++ tomcat/tc5.5.x/trunk/STATUS.txt Wed May 26 02:49:51 2010
@@ -32,12 +32,6 @@ PATCHES PROPOSED TO BACKPORT:
   +1: kkolinko, rjung
   -1:
 
-* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=48179
-  Improve processing of TLD cache file
-  https://issues.apache.org/bugzilla/attachment.cgi?id=24918
-  +1: kkolinko, markt, rjung
-  -1:
-
 * Remove JSSE13Factory, JSSE13SocketFactory classes,
   because
 - TC 5.5 runs on JRE 1.4+ and that comes bundled with JSSE 1.4,

Modified: 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties?rev=948296&r1=948295&r2=948296&view=diff
==
--- 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties
 (original)
+++ 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/LocalStrings.properties
 Wed May 26 02:49:51 2010
@@ -91,7 +91,9 @@ hostConfig.undeploy=Undeploying context 
 hostConfig.undeploy.error=Error undeploying web application at context path {0}
 hostConfig.undeploying=Undeploying deployed web applications
 tldConfig.cce=Lifecycle event data object {0} is not a Context
-tldConfig.execute=Error processing TLD files for context path {0}
+tldConfig.execute=Error processing TLD files for context path [{0}]
+tldConfig.cache.read=Error trying to read a TLD cache file for context path 
[{0}]
+tldConfig.cache.write=Error trying to write a TLD cache file for context path 
[{0}]
 userConfig.database=Exception loading user database
 userConfig.deploy=Deploying web application for user {0}
 userConfig.deploying=Deploying user web applications

Modified: 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/TldConfig.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/TldConfig.java?rev=948296&r1=948295&r2=948296&view=diff
==
--- 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/TldConfig.java
 (original)
+++ 
tomcat/tc5.5.x/trunk/container/catalina/src/share/org/apache/catalina/startup/TldConfig.java
 Wed May 26 02:49:51 2010
@@ -274,8 +274,8 @@ public final class TldConfig implements 
 // find the cache
 if( tldCache!= null && tldCache.exists()) {
 // just read it...
-processCache(tldCache);
-return;
+if (processCache(tldCache))
+return;
 }
 }
 
@@ -290,8 +290,8 @@ public final class TldConfig implements 
 if (tldCache != null && tldCache.exists()) {
 long lastModified = getLastModified(resourcePaths, jarPaths);
 if (lastModified < tldCache.lastModified()) {
-processCache(tldCache);
-return;
+if (processCache(tldCache))
+return;
 }
 }
 
@@ -316,13 +316,29 @@ public final class TldConfig implements 
 
 if( tldCache!= null ) {
 log.debug( "Saving tld cache: " + tldCache + " " + list.length);
+FileOutputStream out = null;
 try {
-FileOutputStream out=new FileOutputStream(tldCache);
+out=new FileOutputStream(tldCache);
 ObjectOutputStream oos=new ObjectOutputStream( out );
 oos.writeObject( list );
 oos.close();
+out = null;
 } catch( IOException ex ) {
-ex.printStackTrace();
+log.warn(sm.getString("tldConfig.cache.write", context
+.getPath()), ex);
+} finally {
+if (out !

DO NOT REPLY [Bug 47878] Deleting JSP file results in a permanent 500 Error, FileNotFound.

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47878

Konstantin Kolinko  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED

--- Comment #2 from Konstantin Kolinko  2010-05-25 
22:33:18 EDT ---
Fixed in 5.5 in r948294. Will be in 5.5.30 onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948294 - in /tomcat/tc5.5.x/trunk: ./ container/webapps/docs/ jasper/src/share/org/apache/jasper/ jasper/src/share/org/apache/jasper/compiler/ jasper/src/share/org/apache/jasper/security/

2010-05-25 Thread kkolinko
Author: kkolinko
Date: Wed May 26 02:31:57 2010
New Revision: 948294

URL: http://svn.apache.org/viewvc?rev=948294&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47878
Return 404's rather than a permanent 500 if a JSP is deleted
Make sure first response post deletion is correct

Modified:
tomcat/tc5.5.x/trunk/STATUS.txt
tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml

tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/JspCompilationContext.java

tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/compiler/Compiler.java

tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/security/SecurityUtil.java

tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/servlet/JspServlet.java

tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/servlet/JspServletWrapper.java

Modified: tomcat/tc5.5.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/STATUS.txt?rev=948294&r1=948293&r2=948294&view=diff
==
--- tomcat/tc5.5.x/trunk/STATUS.txt (original)
+++ tomcat/tc5.5.x/trunk/STATUS.txt Wed May 26 02:31:57 2010
@@ -32,18 +32,6 @@ PATCHES PROPOSED TO BACKPORT:
   +1: kkolinko, rjung
   -1:
 
-* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47878
-  Return 404's rather than a permanent 500 if a JSP is deleted
-  Make sure first response post deletion is correct
-  Port of r439565, r832102 & r904834
-  http://people.apache.org/~markt/patches/2010-01-30-bug47878-tc5.patch
-  (Above patch is wrong - it is missing at least r562752, maybe others)
-  Corrected patch based on Mark's one:
-  http://people.apache.org/~kkolinko/patches/2010-04-22_tc55_bug47878.patch
-  +1: kkolinko, markt, rjung
-  -1:
-
-
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=48179
   Improve processing of TLD cache file
   https://issues.apache.org/bugzilla/attachment.cgi?id=24918

Modified: tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml?rev=948294&r1=948293&r2=948294&view=diff
==
--- tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml (original)
+++ tomcat/tc5.5.x/trunk/container/webapps/docs/changelog.xml Wed May 26 
02:31:57 2010
@@ -111,6 +111,11 @@
 (kkolinko)
   
   
+47878: Return “404”s rather than a permanent
+“500” if a JSP is deleted. Make sure first response after
+deletion is correct. (markt/kkolinko)
+  
+  
 48701: Add a system property to allow disabling enforcement
 of JSP.5.3. The specification recommends, but does not require, this
 enforcement. (kkolinko)

Modified: 
tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/JspCompilationContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/JspCompilationContext.java?rev=948294&r1=948293&r2=948294&view=diff
==
--- 
tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/JspCompilationContext.java
 (original)
+++ 
tomcat/tc5.5.x/trunk/jasper/src/share/org/apache/jasper/JspCompilationContext.java
 Wed May 26 02:31:57 2010
@@ -74,14 +74,13 @@ public class JspCompilationContext {
 private String classPath;
 
 private String baseURI;
-private String baseOutputDir;
 private String outputDir;
 private ServletContext context;
 private URLClassLoader loader;
 
 private JspRuntimeContext rctxt;
 
-private int removed = 0;
+private volatile int removed = 0;
 
 private URLClassLoader jspLoader;
 private URL baseUrl;
@@ -539,16 +538,14 @@ public class JspCompilationContext {
 //  Removal  
 
 public void incrementRemoved() {
-if (removed > 1) {
-jspCompiler.removeGeneratedFiles();
-if( rctxt != null )
-rctxt.removeWrapper(jspUri);
+if (removed == 0 && rctxt != null) {
+rctxt.removeWrapper(jspUri);
 }
 removed++;
 }
 
 public boolean isRemoved() {
-if (removed > 1 ) {
+if (removed > 0 ) {
 return true;
 }
 return false;
@@ -559,7 +556,11 @@ public class JspCompilationContext {
 public void compile() throws JasperException, FileNotFoundException {
 createCompiler();
 if (isPackagedTagFile || jspCompiler.isOutDated()) {
+if (isRemoved()) {
+throw new FileNotFoundException(jspUri);
+}
 try {
+jspCompiler.removeGeneratedFiles();
 jspLoader = null;
 jspCompiler.compile();
 jsw.setReload(true);
@@ -569,7 +570,6 @@ public class JspCompilationContext {
 jsw.setCompilatio

DO NOT REPLY [Bug 48813] Allow the parameter org.apache.el.parser.COERCE_TO_ZERO to be set on runtime

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48813

--- Comment #9 from Ramiro Pereira de Magalhães  
2010-05-25 20:51:10 EDT ---
Hum... This is an important point. Let me think a bit about this and see if I
can make some new proposal that removes such dependency that's worth the
effort.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948258 - /tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 23:48:21 2010
New Revision: 948258

URL: http://svn.apache.org/viewvc?rev=948258&view=rev
Log:
GSOC 2010
Expose additional cluster attributes
Patch provided by chamith buddhika 

Modified:
tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml

Modified: tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml?rev=948258&r1=948257&r2=948258&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml 
(original)
+++ tomcat/trunk/java/org/apache/catalina/ha/deploy/mbeans-descriptors.xml Tue 
May 25 23:48:21 2010
@@ -21,4 +21,20 @@
 domain="Catalina"
 group="Cluster"
 type="org.apache.catalina.ha.deploy.FarmWarDeployer"/>
+
+
+
+
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49234] JMX Descriptor Modifications

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49234

--- Comment #19 from Mark Thomas  2010-05-25 19:45:16 EDT ---
comment #15 - Patch applied
- Doesn't add much since container is unavailable
- More fuel for the separate MBean vs adding methods that return
the
  oname debate

comment #16 - Patch applied
- SimpleTcpReplicationManager is in o.a.c.ha.session package
- Looks like a duplicate. I'm fine with removal.

comment #17 - Huh? That class in in that package. Please re-check.

comment #18 - Applied

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948255 - /tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 23:38:40 2010
New Revision: 948255

URL: http://svn.apache.org/viewvc?rev=948255&view=rev
Log:
GSOC 2010
Expose additional cluster attributes
Patch provided by chamith buddhika 

Modified:
tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml

Modified: tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml?rev=948255&r1=948254&r2=948255&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml (original)
+++ tomcat/trunk/java/org/apache/catalina/ha/mbeans-descriptors.xml Tue May 25 
23:38:40 2010
@@ -20,7 +20,33 @@
 description="Tcp Cluster implementation"
 domain="Catalina"
 group="Cluster"
-type="org.apache.catalina.ha.tcp.SimpleTcpCluster"/>
+type="org.apache.catalina.ha.tcp.SimpleTcpCluster">
+
+
+
+
+
+
+  
   
 
+
 
+  name="nrOfCrossContextSendRequests"
+  description="The number of cross context send requests."
+  type="long"
+  writeable="false"/>
+
+
+
+
+
   
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948254 - /tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 23:37:03 2010
New Revision: 948254

URL: http://svn.apache.org/viewvc?rev=948254&view=rev
Log:
GSOC 2010
Add the container although it isn't much use yet.
Patch provided by chamith buddhika 

Modified:
tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml

Modified: tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml?rev=948254&r1=948253&r2=948254&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml 
(original)
+++ tomcat/trunk/java/org/apache/catalina/deploy/mbeans-descriptors.xml Tue May 
25 23:37:03 2010
@@ -114,6 +114,11 @@
domain="Catalina"
 group="Resources"
  type="org.apache.catalina.deploy.NamingResources">
+ 
+
 
 

svn commit: r948248 - /tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 23:14:06 2010
New Revision: 948248

URL: http://svn.apache.org/viewvc?rev=948248&view=rev
Log: (empty)

Modified:
tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java

Modified: tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java?rev=948248&r1=948247&r2=948248&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/core/StandardContext.java (original)
+++ tomcat/trunk/java/org/apache/catalina/core/StandardContext.java Tue May 25 
22:43:45 2010
@@ -418,7 +418,7 @@ public class StandardContext extends Con
  * The naming resources for this web application.
  */
 private NamingResources namingResources = null;
-
+private ObjectName onameNamingResoucres;
 
 /**
  * The message destinations for this web application.
@@ -1745,7 +1745,10 @@ public class StandardContext extends Con
 namingResources.setContainer(this);
 support.firePropertyChange("namingResources",
oldNamingResources, this.namingResources);
-
+
+unregister(onameNamingResoucres);
+onameNamingResoucres = register(namingResources,
+"type=NamingResources," + getObjectNameKeyProperties());
 }
 
 
@@ -4992,6 +4995,8 @@ public class StandardContext extends Con
 sequenceNumber++);
 broadcaster.sendNotification(notification);
 
+unregister(onameNamingResoucres);
+
 synchronized (instanceListenersLock) {
 instanceListeners = new String[0];
 }
@@ -5542,6 +5547,12 @@ public class StandardContext extends Con
 this.addLifecycleListener(new TldConfig());
 }
 
+// Register the naming resources
+if (namingResources != null) {
+onameNamingResoucres = register(namingResources,
+"type=NamingResources," + getObjectNameKeyProperties());
+}
+
 // Send j2ee.object.created notification 
 if (this.getObjectName() != null) {
 Notification notification = new Notification(

Modified: tomcat/trunk/java/org/apache/catalina/core/StandardServer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/core/StandardServer.java?rev=948232&r1=948231&r2=948232&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/core/StandardServer.java (original)
+++ tomcat/trunk/java/org/apache/catalina/core/StandardServer.java Tue May 25 
22:43:45 2010
@@ -692,6 +692,10 @@ public final class StandardServer extend
 // Register the MBeanFactory
 onameMBeanFactory = register(new MBeanFactory(), "type=MBeanFactory");
 
+// Register the naming resources
+onameNamingResoucres = register(globalNamingResources,
+"type=NamingResources");
+
 // Initialize our defined Services
 for (int i = 0; i < services.length; i++) {
 services[i].init();
@@ -709,11 +713,14 @@ public final class StandardServer extend
 
 unregister(onameStringCache);
 
+unregister(onameNamingResoucres);
+
 super.destroyInternal();
 }
 
 private ObjectName onameStringCache;
 private ObjectName onameMBeanFactory;
+private ObjectName onameNamingResoucres;
 
 /**
  * Obtain the MBean domain for this server. The domain is obtained using



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948222 - /tomcat/tc5.5.x/trunk/STATUS.txt

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 22:16:46 2010
New Revision: 948222

URL: http://svn.apache.org/viewvc?rev=948222&view=rev
Log:
I got over it ;)

Modified:
tomcat/tc5.5.x/trunk/STATUS.txt

Modified: tomcat/tc5.5.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/STATUS.txt?rev=948222&r1=948221&r2=948222&view=diff
==
--- tomcat/tc5.5.x/trunk/STATUS.txt (original)
+++ tomcat/tc5.5.x/trunk/STATUS.txt Tue May 25 22:16:46 2010
@@ -74,6 +74,5 @@ PATCHES PROPOSED TO BACKPORT:
 
 * Fix ByteChunk.indexOf(String, ...) when the string is of length 1
   http://svn.apache.org/viewvc?rev=945231&view=rev
-  +1: kkolinko
-  -0: markt - I'd prefer a patch without the continue mainLoop:
+  +1: kkolinko, markt
   -1:



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948221 - /tomcat/tc6.0.x/trunk/STATUS.txt

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 22:16:27 2010
New Revision: 948221

URL: http://svn.apache.org/viewvc?rev=948221&view=rev
Log:
I got over it ;)

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=948221&r1=948220&r2=948221&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue May 25 22:16:27 2010
@@ -157,25 +157,8 @@ PATCHES PROPOSED TO BACKPORT:
 
 * Fix ByteChunk.indexOf(String, ...) when the string is of length 1
   http://svn.apache.org/viewvc?rev=945231&view=rev
-  +1: kkolinko
+  +1: kkolinko, markt
   -1:
-  -0: markt - I know it is style over substance but that continue mainLoop: is
-  really bugging me. How about this instead:
-Index: java/org/apache/tomcat/util/buf/ByteChunk.java
-===
 java/org/apache/tomcat/util/buf/ByteChunk.java  (revision 947047)
-+++ java/org/apache/tomcat/util/buf/ByteChunk.java  (working copy)
-@@ -684,6 +684,10 @@
- for( int i=myOff+start; i <= (end - srcLen); i++ ) {
- if( buff[i] != first ) continue;
- // found first char, now look for a match
-+if (srcLen == 1) {
-+return i-start;
-+}
-+
- int myPos=i+1;
- for( int srcPos=srcOff + 1; srcPos< srcEnd; ) {
- if( buff[myPos++] != src.charAt( srcPos++ ))
   
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=48990
   Fix the skip.installer build property so once set, the Windows installer is



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 7.0.0 based on Tomcat 7.0.0 RC3

2010-05-25 Thread Sylvain Laurent

On 25 mai 2010, at 21:58, Mark Thomas wrote:

> On 25/05/2010 19:55, Sylvain Laurent wrote:
>> Hello,
>> 
>> how should one file bug reports for this RC3 ? in bugzilla or in the mailing 
>> list ? in BZ the only versions are "trunk" and "unspecified"...
> 
> Trunk is fine for now since anything that affects an RC will almost
> certainly affect trunk. My instinct at this point is to keep the version
> list to just the released versions for now. If that causes problems we
> can easily start adding the RC versions.
> 
> Mark

OK, I filed one in BZ : https://issues.apache.org/bugzilla/show_bug.cgi?id=49340

By the way, speaking of RC3, 
https://issues.apache.org/bugzilla/show_bug.cgi?id=48971 [memory leak 
protection : stopping TimeThreads should be optional and disabled by default] 
is marked for 6.x but it also affects 7.x. It would be nice to take a look at 
it before 7.0.0 (and 6.0.27)...

Sylvain
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49340] New: Webapp unavailable after deploy then stop then start

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49340

   Summary: Webapp unavailable after deploy then stop then start
   Product: Tomcat 7
   Version: trunk
  Platform: Macintosh
Status: NEW
  Severity: normal
  Priority: P2
 Component: Catalina
AssignedTo: dev@tomcat.apache.org
ReportedBy: sylvain.laur...@gmail.com


Occurs with tomcat 7.0 RC3 but not with 6.0.26

Using the manager/html :

- deploy a war
- test one of its page, it should be deployed properly
- stop the webapp
- start the webapp
- test one of its page : FAILURE : tomcat returns a 404.

Notes :
- if using "reload" instead of stop/start it's OK, but it does not fix the
unavailability
- if the webapp is present when tomcat is started, then the stop/start works
normally
- The work around is to undeploy the webapp and redeploy it.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948213 - /tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 21:25:45 2010
New Revision: 948213

URL: http://svn.apache.org/viewvc?rev=948213&view=rev
Log:
Clean-up

Modified:
tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java

Modified: tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java?rev=948213&r1=948212&r2=948213&view=diff
==
--- tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java (original)
+++ tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java Tue May 
25 21:25:45 2010
@@ -32,7 +32,6 @@ import javax.servlet.http.HttpServletReq
 import javax.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.LifecycleState;
-import org.apache.catalina.LifecycleListener;
 import org.apache.catalina.core.StandardServer;
 import org.apache.catalina.core.AprLifecycleListener;
 
@@ -111,7 +110,7 @@ public abstract class TomcatBaseTest ext
 // Add AprLifecycleListener
 StandardServer server = (StandardServer) tomcat.getServer();
 AprLifecycleListener listener = new AprLifecycleListener();
-server.addLifecycleListener((LifecycleListener) listener);
+server.addLifecycleListener(listener);
 
 tomcat.setBaseDir(tempDir.getAbsolutePath());
 tomcat.getHost().setAppBase(appBase.getAbsolutePath());



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 7.0.0 based on Tomcat 7.0.0 RC3

2010-05-25 Thread Mark Thomas
On 25/05/2010 19:55, Sylvain Laurent wrote:
> Hello,
> 
> how should one file bug reports for this RC3 ? in bugzilla or in the mailing 
> list ? in BZ the only versions are "trunk" and "unspecified"...

Trunk is fine for now since anything that affects an RC will almost
certainly affect trunk. My instinct at this point is to keep the version
list to just the released versions for now. If that causes problems we
can easily start adding the RC versions.

Mark

> 
> On 24 mai 2010, at 00:38, Mark Thomas wrote:
> 
>> All,
>>
>> The next Tomcat 7.0.0 release candiate is ready for testing. 7.0.0-RC3
>> can be obtained from:
>> http://people.apache.org/~markt/dev/tomcat-7/v7.0.0-RC3/
>> The svn tag is:
>> http://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/TOMCAT_7_0_0_RC3/
>>
>> Please test this release candidate and provide feedback.
>>
>> The 7.0.0-RC3 tag is
>> [ ] Broken - do not release
>> [ ] Alpha  - go ahead and release 7.0.0 Alpha based on 7.0.0-RC3
>> [ ] Beta   - go ahead and release 7.0.0 Beta based on 7.0.0-RC3
>> [ ] Stable - go ahead and release 7.0.0 Stable based on 7.0.0-RC3
>>
>> The following issues were noted:
>> -
>>
>> Thanks,
>>
>> Mark
>>
>>
>>
>>
>> -
>> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
>> For additional commands, e-mail: dev-h...@tomcat.apache.org
>>
> 
> 
> -
> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
> For additional commands, e-mail: dev-h...@tomcat.apache.org
> 




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 7.0.0 based on Tomcat 7.0.0 RC3

2010-05-25 Thread Sylvain Laurent
Hello,

how should one file bug reports for this RC3 ? in bugzilla or in the mailing 
list ? in BZ the only versions are "trunk" and "unspecified"...

On 24 mai 2010, at 00:38, Mark Thomas wrote:

> All,
> 
> The next Tomcat 7.0.0 release candiate is ready for testing. 7.0.0-RC3
> can be obtained from:
> http://people.apache.org/~markt/dev/tomcat-7/v7.0.0-RC3/
> The svn tag is:
> http://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/TOMCAT_7_0_0_RC3/
> 
> Please test this release candidate and provide feedback.
> 
> The 7.0.0-RC3 tag is
> [ ] Broken - do not release
> [ ] Alpha  - go ahead and release 7.0.0 Alpha based on 7.0.0-RC3
> [ ] Beta   - go ahead and release 7.0.0 Beta based on 7.0.0-RC3
> [ ] Stable - go ahead and release 7.0.0 Stable based on 7.0.0-RC3
> 
> The following issues were noted:
> -
> 
> Thanks,
> 
> Mark
> 
> 
> 
> 
> -
> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
> For additional commands, e-mail: dev-h...@tomcat.apache.org
> 


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948085 - /tomcat/trunk/build.xml

2010-05-25 Thread jfclere
Author: jfclere
Date: Tue May 25 16:08:36 2010
New Revision: 948085

URL: http://svn.apache.org/viewvc?rev=948085&view=rev
Log:
Add missing classes.

Modified:
tomcat/trunk/build.xml

Modified: tomcat/trunk/build.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/build.xml?rev=948085&r1=948084&r2=948085&view=diff
==
--- tomcat/trunk/build.xml (original)
+++ tomcat/trunk/build.xml Tue May 25 16:08:36 2010
@@ -903,6 +903,7 @@
encoding="ISO-8859-1">
   
   
+  
 
   
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948073 - in /tomcat/trunk: java/org/apache/catalina/core/ java/org/apache/catalina/ha/session/ java/org/apache/el/lang/ java/org/apache/jasper/servlet/ modules/jdbc-pool/java/org/apache/t

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 15:18:02 2010
New Revision: 948073

URL: http://svn.apache.org/viewvc?rev=948073&view=rev
Log:
Remove unused imports

Modified:
tomcat/trunk/java/org/apache/catalina/core/StandardServer.java
tomcat/trunk/java/org/apache/catalina/ha/session/ClusterManagerBase.java
tomcat/trunk/java/org/apache/el/lang/ExpressionBuilder.java
tomcat/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java

tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/ConnectionPool.java

tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/DataSource.java

tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/interceptor/StatementCache.java

tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/interceptor/StatementDecoratorInterceptor.java

Modified: tomcat/trunk/java/org/apache/catalina/core/StandardServer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/core/StandardServer.java?rev=948073&r1=948072&r2=948073&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/core/StandardServer.java (original)
+++ tomcat/trunk/java/org/apache/catalina/core/StandardServer.java Tue May 25 
15:18:02 2010
@@ -31,7 +31,6 @@ import java.util.Random;
 
 import javax.management.ObjectName;
 
-import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleState;

Modified: 
tomcat/trunk/java/org/apache/catalina/ha/session/ClusterManagerBase.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/session/ClusterManagerBase.java?rev=948073&r1=948072&r2=948073&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/session/ClusterManagerBase.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/ha/session/ClusterManagerBase.java 
Tue May 25 15:18:02 2010
@@ -19,7 +19,6 @@ package org.apache.catalina.ha.session;
 
 import org.apache.catalina.ha.ClusterManager;
 import java.beans.PropertyChangeListener;
-import org.apache.catalina.Lifecycle;
 import org.apache.catalina.session.ManagerBase;
 import org.apache.catalina.Loader;
 import java.io.ByteArrayInputStream;

Modified: tomcat/trunk/java/org/apache/el/lang/ExpressionBuilder.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/el/lang/ExpressionBuilder.java?rev=948073&r1=948072&r2=948073&view=diff
==
--- tomcat/trunk/java/org/apache/el/lang/ExpressionBuilder.java (original)
+++ tomcat/trunk/java/org/apache/el/lang/ExpressionBuilder.java Tue May 25 
15:18:02 2010
@@ -30,7 +30,6 @@ import javax.el.VariableMapper;
 import org.apache.el.MethodExpressionImpl;
 import org.apache.el.MethodExpressionLiteral;
 import org.apache.el.ValueExpressionImpl;
-import org.apache.el.parser.AstCompositeExpression;
 import org.apache.el.parser.AstDeferredExpression;
 import org.apache.el.parser.AstDynamicExpression;
 import org.apache.el.parser.AstFunction;

Modified: tomcat/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java?rev=948073&r1=948072&r2=948073&view=diff
==
--- tomcat/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java 
(original)
+++ tomcat/trunk/java/org/apache/jasper/servlet/JspServletWrapper.java Tue May 
25 15:18:02 2010
@@ -19,7 +19,6 @@ package org.apache.jasper.servlet;
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.net.URL;
 
 import javax.servlet.Servlet;
 import javax.servlet.ServletConfig;

Modified: 
tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/ConnectionPool.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/ConnectionPool.java?rev=948073&r1=948072&r2=948073&view=diff
==
--- 
tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/ConnectionPool.java
 (original)
+++ 
tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/ConnectionPool.java
 Tue May 25 15:18:02 2010
@@ -35,8 +35,6 @@ import java.util.concurrent.TimeoutExcep
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import javax.sql.XAConnection;
-
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 

Modified: 
tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/DataSource.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/modules/jdbc-pool/java/org/apache/tomcat/jdbc/pool/DataSource.java?rev=948073&r1=948072&r2=948073&view=diff
===

DO NOT REPLY [Bug 49196] NPE in PageContext.getErrorData()

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49196

--- Comment #1 from Mark Thomas  2010-05-25 10:30:40 EDT ---
Fixed in trunk and proposed for 6.0.x

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948058 - /tomcat/tc6.0.x/trunk/STATUS.txt

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 14:22:09 2010
New Revision: 948058

URL: http://svn.apache.org/viewvc?rev=948058&view=rev
Log:
Proposal

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=948058&r1=948057&r2=948058&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue May 25 14:22:09 2010
@@ -195,3 +195,9 @@ Index: java/org/apache/tomcat/util/buf/B
   https://issues.apache.org/bugzilla/attachment.cgi?id=25266
   +1: markt
   -1: 
+
+* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=49196
+  Avoid NPE in PageContext.getErrorData()
+  http://svn.apache.org/viewvc?rev=948057&view=rev
+  +1: markt
+  -1: 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948057 - /tomcat/trunk/java/javax/servlet/jsp/PageContext.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 14:20:58 2010
New Revision: 948057

URL: http://svn.apache.org/viewvc?rev=948057&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=49196
Avoid NPE on PageContext.getErrorData()

Modified:
tomcat/trunk/java/javax/servlet/jsp/PageContext.java

Modified: tomcat/trunk/java/javax/servlet/jsp/PageContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/javax/servlet/jsp/PageContext.java?rev=948057&r1=948056&r2=948057&view=diff
==
--- tomcat/trunk/java/javax/servlet/jsp/PageContext.java (original)
+++ tomcat/trunk/java/javax/servlet/jsp/PageContext.java Tue May 25 14:20:58 
2010
@@ -513,10 +513,18 @@ abstract public class PageContext 
  * @since 2.0
  */
 public ErrorData getErrorData() {
+int status = 0;
+
+Integer status_code = (Integer)getRequest().getAttribute( 
+"javax.servlet.error.status_code");
+// Avoid NPE if attribute is not set
+if (status_code != null) {
+status = status_code.intValue();
+}
+
 return new ErrorData( 
 (Throwable)getRequest().getAttribute( 
"javax.servlet.error.exception" ),
-((Integer)getRequest().getAttribute( 
-"javax.servlet.error.status_code" )).intValue(),
+status,
 (String)getRequest().getAttribute( 
"javax.servlet.error.request_uri" ),
 (String)getRequest().getAttribute( 
"javax.servlet.error.servlet_name" ) );
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948055 - in /tomcat/trunk/test: javax/ javax/servlet/ javax/servlet/jsp/ javax/servlet/jsp/TestPageContext.java webapp-3.0/bug49196.jsp

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 14:20:16 2010
New Revision: 948055

URL: http://svn.apache.org/viewvc?rev=948055&view=rev
Log:
Add a test case for https://issues.apache.org/bugzilla/show_bug.cgi?id=49196
Patch to follow shortly

Added:
tomcat/trunk/test/javax/
tomcat/trunk/test/javax/servlet/
tomcat/trunk/test/javax/servlet/jsp/
tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java   (with props)
tomcat/trunk/test/webapp-3.0/bug49196.jsp   (with props)

Added: tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java?rev=948055&view=auto
==
--- tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java (added)
+++ tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java Tue May 25 
14:20:16 2010
@@ -0,0 +1,43 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package javax.servlet.jsp;
+
+import java.io.File;
+
+import org.apache.catalina.startup.Tomcat;
+import org.apache.catalina.startup.TomcatBaseTest;
+import org.apache.tomcat.util.buf.ByteChunk;
+
+public class TestPageContext extends TomcatBaseTest {
+
+public void testBug49196() throws Exception {
+Tomcat tomcat = getTomcatInstance();
+
+File appDir = new File("test/webapp-3.0");
+// app dir is relative to server home
+tomcat.addWebapp(null, "/test", appDir.getAbsolutePath());
+
+tomcat.start();
+
+ByteChunk res = getUrl("http://localhost:"; + getPort() +
+"/test/bug49196.jsp");
+
+String result = res.toString();
+assertTrue(result.contains("OK"));
+}
+}

Propchange: tomcat/trunk/test/javax/servlet/jsp/TestPageContext.java
--
svn:eol-style = native

Added: tomcat/trunk/test/webapp-3.0/bug49196.jsp
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/webapp-3.0/bug49196.jsp?rev=948055&view=auto
==
--- tomcat/trunk/test/webapp-3.0/bug49196.jsp (added)
+++ tomcat/trunk/test/webapp-3.0/bug49196.jsp Tue May 25 14:20:16 2010
@@ -0,0 +1,26 @@
+<%--
+ Licensed to the Apache Software Foundation (ASF) under one or more
+  contributor license agreements.  See the NOTICE file distributed with
+  this work for additional information regarding copyright ownership.
+  The ASF licenses this file to You under the Apache License, Version 2.0
+  (the "License"); you may not use this file except in compliance with
+  the License.  You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+--%>
+<%
+// As nonsensical as this is, in't shouldn't throw an NPE
+pageContext.getErrorData();
+%>
+
+  Bug 49196 test case
+  
+OK
+  
+
\ No newline at end of file

Propchange: tomcat/trunk/test/webapp-3.0/bug49196.jsp
--
svn:eol-style = native



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948053 - /tomcat/trunk/java/javax/servlet/jsp/PageContext.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 14:16:08 2010
New Revision: 948053

URL: http://svn.apache.org/viewvc?rev=948053&view=rev
Log:
Tabs to spaces

Modified:
tomcat/trunk/java/javax/servlet/jsp/PageContext.java

Modified: tomcat/trunk/java/javax/servlet/jsp/PageContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/javax/servlet/jsp/PageContext.java?rev=948053&r1=948052&r2=948053&view=diff
==
--- tomcat/trunk/java/javax/servlet/jsp/PageContext.java (original)
+++ tomcat/trunk/java/javax/servlet/jsp/PageContext.java Tue May 25 14:16:08 
2010
@@ -109,7 +109,7 @@ abstract public class PageContext 
  * invocation.
  */
 
-public static final int PAGE_SCOPE = 1;
+public static final int PAGE_SCOPE = 1;
 
 /**
  * Request scope: the named reference remains available from the 
@@ -117,7 +117,7 @@ abstract public class PageContext 
  * is completed.
  */
 
-public static final int REQUEST_SCOPE  = 2;
+public static final int REQUEST_SCOPE = 2;
 
 /**
  * Session scope (only valid if this page participates in a session):
@@ -125,14 +125,14 @@ abstract public class PageContext 
  * associated with the Servlet until the HttpSession is invalidated.
  */
 
-public static final int SESSION_SCOPE  = 3;
+public static final int SESSION_SCOPE = 3;
 
 /**
  * Application scope: named reference remains available in the 
  * ServletContext until it is reclaimed.
  */
 
-public static final int APPLICATION_SCOPE  = 4;
+public static final int APPLICATION_SCOPE = 4;
 
 /**
  * Name used to store the Servlet in this PageContext's nametables.
@@ -410,7 +410,7 @@ abstract public class PageContext 
  * @since 2.0
  */
 abstract public void include(String relativeUrlPath, boolean flush) 
-   throws ServletException, IOException;
+throws ServletException, IOException;
 
 /**
  * 
@@ -513,12 +513,12 @@ abstract public class PageContext 
  * @since 2.0
  */
 public ErrorData getErrorData() {
-   return new ErrorData( 
-   (Throwable)getRequest().getAttribute( 
"javax.servlet.error.exception" ),
-   ((Integer)getRequest().getAttribute( 
-   "javax.servlet.error.status_code" )).intValue(),
-   (String)getRequest().getAttribute( 
"javax.servlet.error.request_uri" ),
-   (String)getRequest().getAttribute( 
"javax.servlet.error.servlet_name" ) );
+return new ErrorData( 
+(Throwable)getRequest().getAttribute( 
"javax.servlet.error.exception" ),
+((Integer)getRequest().getAttribute( 
+"javax.servlet.error.status_code" )).intValue(),
+(String)getRequest().getAttribute( 
"javax.servlet.error.request_uri" ),
+(String)getRequest().getAttribute( 
"javax.servlet.error.servlet_name" ) );
 }
 
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49095] org.apache.tomcat.util.net.AprEndpoint.unlockAccept does not wakeup accepts with deferred accept or BSD filters

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49095

--- Comment #1 from Mark Thomas  2010-05-25 09:56:53 EDT ---
Fixed in trunk and proposed for 6.0.x.
Thanks for the patch.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948044 - /tomcat/tc6.0.x/trunk/STATUS.txt

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 13:56:18 2010
New Revision: 948044

URL: http://svn.apache.org/viewvc?rev=948044&view=rev
Log:
Proposals

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=948044&r1=948043&r2=948044&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue May 25 13:56:18 2010
@@ -184,4 +184,14 @@ Index: java/org/apache/tomcat/util/buf/B
   +1: markt
   -1: 
 
-  
+* Fix issues running AJP BIO coyote connector under a security manager
+  http://svn.apache.org/viewvc?rev=947717&view=rev
+  +1: markt
+  -1: 
+
+* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=49095
+  AprEndpoint does not wakeup accepts with deferred accept or BSD filters
+  Based on a patch provided by Ruediger Pluem
+  https://issues.apache.org/bugzilla/attachment.cgi?id=25266
+  +1: markt
+  -1: 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948043 - /tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 13:53:14 2010
New Revision: 948043

URL: http://svn.apache.org/viewvc?rev=948043&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=49095
AprEndpoint does not wakeup accepts with deferred accept or BSD filters
Based on a patch provided by Ruediger Pluem

Modified:
tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java

Modified: tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java?rev=948043&r1=948042&r2=948043&view=diff
==
--- tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java (original)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java Tue May 25 
13:53:14 2010
@@ -17,6 +17,8 @@
 
 package org.apache.tomcat.util.net;
 
+import java.io.PrintWriter;
+import java.net.InetSocketAddress;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
@@ -578,6 +580,59 @@ public class AprEndpoint extends Abstrac
 
 
 /**
+ * Unlock the server socket accept using a bogus connection.
+ */
+@Override
+protected void unlockAccept() {
+java.net.Socket s = null;
+InetSocketAddress saddr = null;
+try {
+// Need to create a connection to unlock the accept();
+if (getAddress() == null) {
+saddr = new InetSocketAddress("localhost", getPort());
+} else {
+saddr = new InetSocketAddress(getAddress(),getPort());
+}
+s = new java.net.Socket();
+s.setSoTimeout(getSocketProperties().getSoTimeout());
+// TODO Consider hard-coding to s.setSoLinger(true,0)
+
s.setSoLinger(getSocketProperties().getSoLingerOn(),getSocketProperties().getSoLingerTime());
+if (log.isDebugEnabled()) {
+log.debug("About to unlock socket for:"+saddr);
+}
+s.connect(saddr,getSocketProperties().getUnlockTimeout());
+/*
+ * In the case of a deferred accept / accept filters we need to
+ * send data to wake up the accept. Send OPTIONS * to bypass even
+ * BSD accept filters. The Acceptor will discard it.
+ */
+if (deferAccept) {
+PrintWriter pw;
+
+pw = new PrintWriter(s.getOutputStream());
+pw.print("OPTIONS * HTTP/1.0\r\n" +
+ "User-Agent: Tomcat wakeup connection\r\n\r\n");
+pw.flush();
+}
+if (log.isDebugEnabled()) {
+log.debug("Socket unlock completed for:"+saddr);
+}
+} catch(Exception e) {
+if (log.isDebugEnabled()) {
+log.debug(sm.getString("endpoint.debug.unlock", "" + 
getPort()), e);
+}
+} finally {
+if (s != null) {
+try {
+s.close();
+} catch (Exception e) {
+// Ignore
+}
+}
+}
+}
+
+/**
  * Pause the endpoint, which will make it stop accepting new sockets.
  */
 @Override
@@ -823,6 +878,15 @@ public class AprEndpoint extends Abstrac
 try {
 // Accept the next incoming connection from the server 
socket
 long socket = Socket.accept(serverSock);
+/*
+ * In the case of a deferred accept unlockAccept needs to
+ * send data. This data will be rubbish, so destroy the
+ * socket and don't process it.
+ */
+if (deferAccept && (paused || !running)) {
+Socket.destroy(socket);
+continue;
+}
 // Hand this socket off to an appropriate processor
 if (!processSocketWithOptions(socket)) {
 // Close socket and pool right away



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49335] Client certificate not passed to Tomcat

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49335

--- Comment #4 from Mark Thomas  2010-05-25 09:28:47 EDT ---
That sounds like it. I had SSLOptions +StdEnvVars but not SSLOptions
+ExportCertData"

I'll test this when I am back in front of that machine and re-open if I still
have an issue.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49335] Client certificate not passed to Tomcat

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49335

Rainer Jung  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||WORKSFORME

--- Comment #3 from Rainer Jung  2010-05-25 08:57:52 
EDT ---
The solution should be: add "SSLOptions +ExportCertData", and if you want to
get information like SSL session id, etc. in addition also add "SSLOptions
+StdEnvVars". Confirmed by code inspection and by testing.

mod_proxy gets the data directly from mod_ssl through an ssl variable lookup.
mod_jk uses the export to environment feature of mod_ssl, which has to be
activated explicitely.

I added a note about that to the docs pages "Apache Reference" and "Reverse
Proxy HowTo". See r948029.

Please reopen, if it does still not work. Thanks for the report.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948029 - in /tomcat/jk/trunk/xdocs: generic_howto/proxy.xml miscellaneous/changelog.xml reference/apache.xml

2010-05-25 Thread rjung
Author: rjung
Date: Tue May 25 12:52:27 2010
New Revision: 948029

URL: http://svn.apache.org/viewvc?rev=948029&view=rev
Log:
Add SSLOptions needed for SSL information forwarding
to documentation.

Modified:
tomcat/jk/trunk/xdocs/generic_howto/proxy.xml
tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml
tomcat/jk/trunk/xdocs/reference/apache.xml

Modified: tomcat/jk/trunk/xdocs/generic_howto/proxy.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/generic_howto/proxy.xml?rev=948029&r1=948028&r2=948029&view=diff
==
--- tomcat/jk/trunk/xdocs/generic_howto/proxy.xml (original)
+++ tomcat/jk/trunk/xdocs/generic_howto/proxy.xml Tue May 25 12:52:27 2010
@@ -90,6 +90,11 @@ if tomcatAuthentication="false"
 query string: getQueryString()
 
+
+The following additional SSL-related data will be made available by Apache and 
forwarded by mod_jk only
+if you set SSLOptions +StdEnvVars. For the certificate 
information you also need
+to set SSLOptions +ExportCertData.
+
 SSL cipher: getAttribute(javax.servlet.request.cipher_suite)
 
 SSL key size: getAttribute(javax.servlet.request.key_size).

Modified: tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml?rev=948029&r1=948028&r2=948029&view=diff
==
--- tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml (original)
+++ tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml Tue May 25 12:52:27 2010
@@ -55,6 +55,9 @@
 to prevent conversion of underscores '_' to hyphens '-' in header 
names.
 Old behaviour can be enabled by defining USE_CGI_HEADERS. (timw)
   
+  
+Docs: Document SSLOptions needed for SSL information forwarding. 
(rjung)
+  
   
 Docs: Grammar and style improvements and clarification about serving
 static content by IIS.

Modified: tomcat/jk/trunk/xdocs/reference/apache.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/reference/apache.xml?rev=948029&r1=948028&r2=948029&view=diff
==
--- tomcat/jk/trunk/xdocs/reference/apache.xml (original)
+++ tomcat/jk/trunk/xdocs/reference/apache.xml Tue May 25 12:52:27 2010
@@ -267,6 +267,10 @@ is turned off.
 Turns on SSL processing and information gathering by mod_jk
 
 The default value is On.
+
+In order to make SSL data available for mod_jk in Apache, you need to
+set SSLOptions +StdEnvVars. For the certificate information you 
also need
+to add SSLOptions +ExportCertData.
 
 
 Name of the Apache environment variable that contains SSL indication.



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948028 - /tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 12:50:19 2010
New Revision: 948028

URL: http://svn.apache.org/viewvc?rev=948028&view=rev
Log:
Remove duplicate code

Modified:
tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java

Modified: tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java?rev=948028&r1=948027&r2=948028&view=diff
==
--- tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java (original)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/AprEndpoint.java Tue May 25 
12:50:19 2010
@@ -102,16 +102,6 @@ public class AprEndpoint extends Abstrac
 
 
 /**
- * Priority of the acceptor and poller threads.
- */
-protected int threadPriority = Thread.NORM_PRIORITY;
-@Override
-public void setThreadPriority(int threadPriority) { this.threadPriority = 
threadPriority; }
-@Override
-public int getThreadPriority() { return threadPriority; }
-
-
-/**
  * Size of the socket poller.
  */
 protected int pollerSize = 8 * 1024;



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49038] Crash in tcnative

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49038

Mark Thomas  changed:

   What|Removed |Added

  Component|Catalina|Library
Version|6.0.14  |1.1.16
Product|Tomcat 6|Tomcat Native
   Target Milestone|default |---

--- Comment #5 from Mark Thomas  2010-05-25 08:14:26 EDT ---
Moving to Native

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 7.0.0 based on Tomcat 7.0.0 RC3

2010-05-25 Thread Mark Thomas

On 25/05/2010 10:38, jean-frederic clere wrote:

On 05/25/2010 01:04 AM, Mark Thomas wrote:

On 23/05/2010 23:38, Mark Thomas wrote:

All,

The next Tomcat 7.0.0 release candiate is ready for testing. 7.0.0-RC3
can be obtained from:
http://people.apache.org/~markt/dev/tomcat-7/v7.0.0-RC3/
The svn tag is:
http://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/TOMCAT_7_0_0_RC3/

Please test this release candidate and provide feedback.

The 7.0.0-RC3 tag is
[ ] Broken - do not release
[ ] Alpha  - go ahead and release 7.0.0 Alpha based on 7.0.0-RC3
[X] Beta   - go ahead and release 7.0.0 Beta based on 7.0.0-RC3
[ ] Stable - go ahead and release 7.0.0 Stable based on 7.0.0-RC3


Servlet TCK passes with security manager for HTTP BIO
Servlet TCK passes with security manager for HTTP NIO apart from
CLIENT-CERT [1]
Servlet TCK passes with security manager for HTTP APR/native
Servlet TCK fails with security manager for AJP BIO [2]
Servlet TCK fails with security manager for AJP APR/native [3]
JSP TCK passes with security manager for HTTP BIO
EL TCK passes with security manager

I don't see any show-stoppers in the current open bug list.

The following issues were noted:
- [1] https://issues.apache.org/bugzilla/show_bug.cgi?id=49284
- [2] Security manager specific issues - fixed in r947717
- [3] Async issues - may be one issue breaking subsequent tests

[1] has been thay way for numerous stable 6.0.x releases, [3] can be
worked around by not using APR/native


hm according to your mail AJP is always failing, no?


Nope. AJP BIO without the security manager is fine.

Mark

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: org.apache.catalina.Core MBeans Descriptor Modifications

2010-05-25 Thread Mark Thomas

On 23/05/2010 04:57, buddhika chamith wrote:

Hi All,

It seems that o.a.Catalina.Core MBeans descriptor has got operations
containing POJO objects instead of primitive types which make them
inaccessible via JConsole.
I suggest the following to avoid this situation. Any comments and
suggestions are appreciated.


*Class: StandardContext *
'
Method : addValve (org.apache.catalina.Valve)
Suggestion : Modify the signature to addValve(String className) where
className is that of the Valve to be instantiated. This is acceptable since
all the Valve classes have no arg constructors AFA I noticed.

Method : removeValve(org.apache.catalina.Valve)
Suggestion :   Modify the signature to removeValve(String oname)


I wouldn't modify these methods, I would add new ones - probably to 
ContainerBase along the lines of:

addValve(String oname)
removeValve(String oname)

That way, you can use the MBean Factory to create and register the valve 
and the oname to add it to a component. I haven't confirmed this but it 
should be do-able.



Methods   :
add/removeLifecycleListener(org.apache.catalina.LifecycleListener)
Suggestion  :  Remove the methods since the method can be provided in a
generic way with only involving primitives. Any ideas on this?


I don't understand what you mean here.


These methods can be included in a seperate MBean class
(e.g:StandardContextMBean) so that original class interface is left intact.


Ah. The method changes above make more sense now. I'm not sure about 
this. My instinct is to prefer not to have a separate class as that is 
one more thing to keep in sync. I can see how it would be useful. I 
think this is a case of needing to look at both options and deciding 
which is best.



*Class: StandardEngine*

Method   :addChild(org.apache.catalina.Container)
Suggestion   :addHost(String name, String appBase, boolean
autoDeploy,boolean deployOnStartup,boolean deployXML, boolean unpackWARs)

This method can be included in a seperate MBean class so that original class
interface is left intact. Since only a host can be added as a child mbean
method name can be named as addHost to remove any ambiguity.

*Class: StandardHost*

Method:  addChild(org.apache.catalina.Container)
Suggestion:  addContext(String path, String docBase, boolean
xmlValidation, boolean xmlNamespaceAware, boolean tldValidation, boolean
tldNamespaceAware)


*Class: StandardService*

Method:  addConnector(org.apache.catalina.connector.Connector)
Suggestion:   addConnector(String address, int port, boolean isAjp,
boolean isSSL)


Same comment as above re separate MBean classes vs methods using oname.


*Class: StandardWrapper*

Method :
add/removeLifeCycleListener(org.apache.catalina.LifecycleListener)
Suggestion : Remove the methods since the method can be provided in a
generic way with only involving primitives.


Again, I don't get what you mean here.

Mark



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 7.0.0 based on Tomcat 7.0.0 RC3

2010-05-25 Thread jean-frederic clere
On 05/25/2010 01:04 AM, Mark Thomas wrote:
> On 23/05/2010 23:38, Mark Thomas wrote:
>> All,
>>
>> The next Tomcat 7.0.0 release candiate is ready for testing. 7.0.0-RC3
>> can be obtained from:
>> http://people.apache.org/~markt/dev/tomcat-7/v7.0.0-RC3/
>> The svn tag is:
>> http://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/TOMCAT_7_0_0_RC3/
>>
>> Please test this release candidate and provide feedback.
>>
>> The 7.0.0-RC3 tag is
>> [ ] Broken - do not release
>> [ ] Alpha  - go ahead and release 7.0.0 Alpha based on 7.0.0-RC3
>> [X] Beta   - go ahead and release 7.0.0 Beta based on 7.0.0-RC3
>> [ ] Stable - go ahead and release 7.0.0 Stable based on 7.0.0-RC3
> 
> Servlet TCK passes with security manager for HTTP BIO
> Servlet TCK passes with security manager for HTTP NIO apart from
> CLIENT-CERT [1]
> Servlet TCK passes with security manager for HTTP APR/native
> Servlet TCK fails with security manager for AJP BIO [2]
> Servlet TCK fails with security manager for AJP APR/native [3]
> JSP TCK passes with security manager for HTTP BIO
> EL TCK passes with security manager
> 
> I don't see any show-stoppers in the current open bug list.
> 
> The following issues were noted:
> - [1] https://issues.apache.org/bugzilla/show_bug.cgi?id=49284
> - [2] Security manager specific issues - fixed in r947717
> - [3] Async issues - may be one issue breaking subsequent tests
> 
> [1] has been thay way for numerous stable 6.0.x releases, [3] can be
> worked around by not using APR/native

hm according to your mail AJP is always failing, no?

Cheers

Jean-Frederic

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r947974 - /tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java

2010-05-25 Thread jfclere
Author: jfclere
Date: Tue May 25 09:13:15 2010
New Revision: 947974

URL: http://svn.apache.org/viewvc?rev=947974&view=rev
Log:
It would a lot of work to have it switchable in APR.

Modified:
tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java

Modified: tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java?rev=947974&r1=947973&r2=947974&view=diff
==
--- tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java (original)
+++ tomcat/trunk/test/org/apache/catalina/startup/TestTomcatSSL.java Tue May 25 
09:13:15 2010
@@ -217,6 +217,12 @@ public class TestTomcatSSL extends Tomca
 tomcat.getConnector().setAttribute("allowUnsafeLegacyRenegotiation", 
"true");
 
 tomcat.start();
+
+String protocol = tomcat.getConnector().getProtocolHandlerClassName();
+if (protocol.indexOf("Apr") != -1) {
+return; // Not supported yet (10/05/25)
+}
+
 SSLContext sslCtx = SSLContext.getInstance("TLS");
 sslCtx.init(null, trustAllCerts, new java.security.SecureRandom());
 SSLSocketFactory socketFactory = sslCtx.getSocketFactory();



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49335] Client certificate not passed to Tomcat

2010-05-25 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49335

--- Comment #2 from Mark Thomas  2010-05-25 04:20:52 EDT ---
(In reply to comment #1)
> Is it reproducible in 7.0 RC3 only, or in 6.0.x as well?
Both. Given that the mod_jk logs showed that no certificate was being sent,
this is expected. 

> Is Tomcat running with 32-bit or 64-bit JRE? Is Tomcat-Native used?
Not relevant. This isn't an AJP connector issue.

> Does this certificate fit into a single AJP packet, along with other request
> headers? Sure that it does fit, because otherwise there must be an error
> logged.
Yes, else a) there would be an error and b) mod_proxy_ajp wouldn't work either.

> What JkOptions directives are used in the configuration?
The bare minimum:
JkWorkersFileconf/workers.properties
JkShmFilelogs/mod_jk.shm
JkLogFilelogs/mod_jk.log

Non-SSL requests work without issue.

The relevant parts of the SSL virtual host are:

SSLVerifyClientrequire


This works:
ProxyPass /bugs-tc5/bug37869.jsp ajp://localhost:8009/bugs-tc5/bug37869.jsp

This fails:
JkMount /bugs-tc5/bug37869.jsp worker1

That JSP is configured on the Tomcat side to require SSL, require a specific
client certificate and to display the DN of the supplied cert.

With mod_proxy_ajp everything works.

With mod_jk no certificate is present in the request received by Tomcat. This
has been verified a) bu reviewing the mod_jk logs, b) debugging Tomcat parsing
the AJP request.

--- tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java (original)
+++ tomcat/trunk/test/org/apache/catalina/startup/TomcatBaseTest.java Tue May 
25 23:14:06 2010
@@ -100,6 +100,8 @@ public abstract class TomcatBaseTest ext
 fail("Unable to create temporary directory for test");
 }
 
+System.setProperty("catalina.base", tempDir.getAbsolutePath());
+
 File appBase = new File(tempDir, "webapps");
 if (!appBase.exists() && !appBase.mkdir()) {
 fail("Unable to create appBase for test");



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948233 - /tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 22:44:21 2010
New Revision: 948233

URL: http://svn.apache.org/viewvc?rev=948233&view=rev
Log:
Make test more exact. Want to spot any change in the number of MBeans.

Modified:
tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java

Modified: tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java?rev=948233&r1=948232&r2=948233&view=diff
==
--- tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java 
(original)
+++ tomcat/trunk/test/org/apache/catalina/mbeans/TestRegistration.java Tue May 
25 22:44:21 2010
@@ -54,9 +54,9 @@ public class TestRegistration extends To
 onames = mbeanServer.queryNames(new ObjectName("Catalina:*"), null);
 assertEquals("Found: " + onames, 0, onames.size());
 
 // Verify there are some Tomcat MBeans
 onames = mbeanServer.queryNames(new ObjectName("Tomcat:*"), null);
-assertTrue("Not enough Tomcat MBeans", onames.size() >= 20);
+assertEquals("Wrong number of Tomcat MBeans", 22, onames.size());
 
 tomcat.stop();
 



-
@@ -54,9 +54,9 @@ public class TestRegistration extends To
 assertEquals("Found: " + onames, 0, onames.size());
 
-// Verify there are some Tomcat MBeans
+// Verify there are the correct number of Tomcat MBeans
 onames = mbeanServer.queryNames(new ObjectName("Tomcat:*"), null);
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r948232 - in /tomcat/trunk/java/org/apache/catalina/core: StandardContext.java StandardServer.java

2010-05-25 Thread markt
Author: markt
Date: Tue May 25 22:43:45 2010
New Revision: 948232

URL: http://svn.apache.org/viewvc?rev=948232&view=rev
Log:
Restore the naming resource MBeans

Modified:
tomcat/trunk/java/org/apache/catalina/core/StandardContext.java
tomcat/trunk/java/org/apache/catalina/core/StandardServer.java

Modified: tomcat/trunk/java/org/apache/catalina/core/StandardContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/core/StandardContext.java?rev=948232&r1=948231&r2=948232&view=diff
==
-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Page Van Ramirez deleted from Tomcat Wiki

2010-05-25 Thread Apache Wiki
Dear wiki user,

You have subscribed to a wiki page "Tomcat Wiki" for change notification.

The page "Van Ramirez" has been deleted by markt.
The comment on this change is: Spam.
http://wiki.apache.org/tomcat/Van%20Ramirez

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r947952 - in /tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http: spdyreq0.bin spdyreqCompressed.bin

2010-05-25 Thread costin
Author: costin
Date: Tue May 25 07:37:23 2010
New Revision: 947952

URL: http://svn.apache.org/viewvc?rev=947952&view=rev
Log:
Missed 2 files - older version of the protocol, will update them when I get to 
the new proto.

Added:

tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreq0.bin  
 (with props)

tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreqCompressed.bin
   (with props)

Added: 
tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreq0.bin
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreq0.bin?rev=947952&view=auto
==
Binary file - no diff available.

Propchange: 
tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreq0.bin
--
svn:mime-type = application/octet-stream

Added: 
tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreqCompressed.bin
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreqCompressed.bin?rev=947952&view=auto
==
Binary file - no diff available.

Propchange: 
tomcat/trunk/modules/tomcat-lite/test/org/apache/tomcat/lite/http/spdyreqCompressed.bin
--
svn:mime-type = application/octet-stream



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Tomcat Wiki] Update of "Van Ramirez" by Van Ramirez

2010-05-25 Thread Apache Wiki
Dear Wiki user,

You have subscribed to a wiki page or wiki category on "Tomcat Wiki" for change 
notification.

The "Van Ramirez" page has been changed by Van Ramirez.
http://wiki.apache.org/tomcat/Van%20Ramirez?action=diff&rev1=4&rev2=5

--

  Describe Van Ramirez here.
  
+ I am Van Ramirez a staff of iRentCanada.ca a company in Canada that offers 
and supply to the renter’s a directory listings of rental properties like 
[[http://www.irentcanada.ca/html/calgary_rentals.php|calgary apartment 
rentals]] and[[http://www.irentcanada.ca/html/calgary_rentals.php|calgary 
apartments]].
+ 

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Tomcat Wiki] Update of "Van Ramirez" by Van Ramirez

2010-05-25 Thread Apache Wiki
Dear Wiki user,

You have subscribed to a wiki page or wiki category on "Tomcat Wiki" for change 
notification.

The "Van Ramirez" page has been changed by Van Ramirez.
http://wiki.apache.org/tomcat/Van%20Ramirez?action=diff&rev1=2&rev2=3

--

- Describe Van Ramirez here.I am Van Ramirez a staff of iRentCanada.ca a 
company in Canada that offers and supply to the renter’s a directory listings 
of rental properties like 
[url=http://www.irentcanada.ca/html/calgary_rentals.php]calgary apartment 
rentals[/url]
+ Describe Van Ramirez here.I am Van Ramirez a staff of iRentCanada.ca a 
company in Canada that offers and supply to the renter’s a directory listings 
of rental properties like 
- [url=http://www.irentcanada.ca/html/calgary_rentals.php]calgary 
apartments[/url]
+ "calgary apartment rentals":http://www.irentcanada.ca/html/calgary_rentals.php
+ "calgary apartments":http://www.irentcanada.ca/html/calgary_rentals.php
  

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Tomcat Wiki] Update of "Van Ramirez" by Van Ramirez

2010-05-25 Thread Apache Wiki
Dear Wiki user,

You have subscribed to a wiki page or wiki category on "Tomcat Wiki" for change 
notification.

The "Van Ramirez" page has been changed by Van Ramirez.
http://wiki.apache.org/tomcat/Van%20Ramirez?action=diff&rev1=1&rev2=2

--

- Describe Van Ramirez here.I am Van Ramirez a staff of iRentCanada.ca a 
company in Canada that offers and supply to the renter’s a directory listings 
of rental properties like http://www.irentcanada.ca/html/calgary_rentals.php";>calgary apartment 
rentals and http://www.irentcanada.ca/html/calgary_rentals.php";>calgary 
apartments.
+ Describe Van Ramirez here.I am Van Ramirez a staff of iRentCanada.ca a 
company in Canada that offers and supply to the renter’s a directory listings 
of rental properties like 
[url=http://www.irentcanada.ca/html/calgary_rentals.php]calgary apartment 
rentals[/url]
+ [url=http://www.irentcanada.ca/html/calgary_rentals.php]calgary 
apartments[/url]
  

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Tomcat Wiki] Update of "Van Ramirez" by Van Ramirez

2010-05-25 Thread Apache Wiki
Dear Wiki user,

You have subscribed to a wiki page or wiki category on "Tomcat Wiki" for change 
notification.

The "Van Ramirez" page has been changed by Van Ramirez.
http://wiki.apache.org/tomcat/Van%20Ramirez

--

New page:
Describe Van Ramirez here.I am Van Ramirez a staff of iRentCanada.ca a company 
in Canada that offers and supply to the renter’s a directory listings of rental 
properties like http://www.irentcanada.ca/html/calgary_rentals.php";>calgary apartment 
rentals and http://www.irentcanada.ca/html/calgary_rentals.php";>calgary 
apartments.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org